@@ -124,7 +124,7 @@ class Cookbook:
             return False
 
         if os.listdir(cls.get_recipe_basedir()):
-            print(f"recipes' repo already in {cls.get_recipe_basedir()}: remove it if you want to add a different one")
+            print(f"recipes' repository already in '{cls.get_recipe_basedir()}':\nremove it if you want to add a different one")
             return False
 
         try:
@@ -148,6 +148,6 @@ def _clone_recipes_src(recipe_src: RecipeSource, destination: str):
 
 
 def _find_path_to_dir(basedir, dirname):
-    for dirpath, dirs, files in os.walk(os.path.expanduser(basedir)):
+    for dirpath, dirs, files in os.walk(os.path.expanduser(basedir), followlinks=True):
         if dirname in dirs:
             return os.path.join(dirpath, dirname)
